package Acme::MySecondModule::SADAMS;
use 5.008001;
use strict;
use warnings;

our $VERSION = "0.03";

sub a { }
sub b { }
sub c { }
sub d { }

1;
__END__

=encoding utf-8

=head1 NAME

Acme::MySecondModule::SADAMS - It's new $module

=head1 SYNOPSIS

    use Acme::MySecondModule::SADAMS;

=head1 DESCRIPTION

Acme::MySecondModule::SADAMS is ...

=head1 LICENSE

Copyright (C) Stefan Adams.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

Stefan Adams E<lt>stefan@borgia.comE<gt>

=cut

